import "./App.css";
import React from "react";
import {
  AppBar,
  Box,
  CssBaseline,
  Drawer,
  IconButton,
  List,
  ListItem,
  ListItemText,
  Toolbar,
  Typography,
} from "@mui/material";
import { styled } from "@mui/material/styles";
import MenuIcon from "@mui/icons-material/Menu";

// 参考：https://mui.com/material-ui/react-drawer/#persistent-drawer
const Main = styled("main", { shouldForwardProp: (prop) => prop !== "open" })<{
  open?: boolean;
}>(({ theme, open }) => ({
  flexGrow: 1,
  padding: theme.spacing(3),
  transition: theme.transitions.create("margin", {
    easing: theme.transitions.easing.easeIn,
    duration: theme.transitions.duration.leavingScreen,
  }),
  marginLeft: -250,
  ...(open && {
    transition: theme.transitions.create("margin", {
      easing: theme.transitions.easing.easeOut,
      duration: theme.transitions.duration.enteringScreen,
    }),
    marginLeft: 0,
  }),
}));

function App() {
  const [isOpen, setOpenState] = React.useState<boolean>(true);
  const toggleOpenState = (): void => {
    setOpenState(!isOpen);
  };
  return (
    <Box sx={{ display: "flex" }}>
      <CssBaseline />
      {/* AppBar */}
      <Box sx={{ display: "flex" }}>
        <AppBar
          position="fixed"
          sx={{ zIndex: (theme) => theme.zIndex.drawer + 1 }}
        >
          <Toolbar>
            <IconButton
              color="inherit"
              aria-label="open drawer"
              edge="end"
              onClick={toggleOpenState}
              sx={{ mr: 2 }}
            >
              <MenuIcon />
            </IconButton>
            <Typography
              variant="h6"
              noWrap
              component="div"
              sx={{ display: "block" }}
            >
              タイトル
            </Typography>
          </Toolbar>
        </AppBar>
      </Box>
      {/* AppBar */}

      {/* Drawer */}
      {/* 参考：https://mui.com/material-ui/react-drawer/#clipped-under-the-app-bar */}
      <Drawer
        sx={{
          width: 250,
          flexShrink: 0,
          "& .MuiDrawer-paper": {
            width: 250,
          },
        }}
        variant="persistent"
        anchor="left"
        open={isOpen}
      >
        <Toolbar />
        <Box sx={{ overflow: "auto" }}>
          <List>
            <ListItem button>
              <ListItemText primary="メニュー１" />
            </ListItem>
            <ListItem button>
              <ListItemText primary="メニュー２" />
            </ListItem>
          </List>
        </Box>
      </Drawer>
      {/* Drawer */}

      {/* Main */}
      {/* 参考：https://mui.com/material-ui/react-drawer/#persistent-drawer */}
      <Main open={isOpen}>
        <Toolbar />
        <div>メイン</div>
      </Main>
      {/* Main */}
    </Box>
  );
}

export default App;
